import os

DEBUG = True

SECRET_KEY = '^7jcx7^h#b@%a76lr@a2!7xj#@4@5ayuyan9c$y#(_(8l3)_%t'

INSTALLED_APPS = [
    'kagiso_image',

    'wagtail.wagtailadmin',
    'wagtail.wagtailcore',
    'wagtail.wagtaildocs',
    'wagtail.wagtailembeds',
    'wagtail.wagtailforms',
    'wagtail.wagtailimages',
    'wagtail.wagtailredirects',
    'wagtail.wagtailsearch',
    'wagtail.wagtailsites',
    'wagtail.wagtailsnippets',
    'wagtail.wagtailusers',

    'modelcluster',
    'taggit',

    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
]

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.security.SecurityMiddleware',

    'wagtail.wagtailcore.middleware.SiteMiddleware',
    'wagtail.wagtailredirects.middleware.RedirectMiddleware',
)

# ROOT_URLCONF = 'auth_backend.urls'

WSGI_APPLICATION = 'kagiso_image.wsgi.application'

# Database
# https://docs.djangoproject.com/en/1.7/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'HOST': 'localhost',
        'NAME': 'kagiso_image',
        'USER': 'postgres',
        'PASSWORD': 'password',
    }
}



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings
import wagtail.wagtailadmin.taggable
import wagtail.wagtailimages.models
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0002_auto_20150616_2121'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('wagtailimages', '0008_image_created_at_index'),
    ]

    operations = [
        migrations.CreateModel(
            name='ImageWithAttribution',
            fields=[
                ('id', models.AutoField(verbose_name='ID', primary_key=True, serialize=False, auto_created=True)),
                ('title', models.CharField(verbose_name='Title', max_length=255)),
                ('file', models.ImageField(verbose_name='File', height_field='height', width_field='width', upload_to=wagtail.wagtailimages.models.get_upload_to)),
                ('width', models.IntegerField(verbose_name='Width', editable=False)),
                ('height', models.IntegerField(verbose_name='Height', editable=False)),
                ('created_at', models.DateTimeField(verbose_name='Created at', auto_now_add=True, db_index=True)),
                ('focal_point_x', models.PositiveIntegerField(blank=True, null=True)),
                ('focal_point_y', models.PositiveIntegerField(blank=True, null=True)),
                ('focal_point_width', models.PositiveIntegerField(blank=True, null=True)),
                ('focal_point_height', models.PositiveIntegerField(blank=True, null=True)),
                ('file_size', models.PositiveIntegerField(editable=False, null=True)),
                ('attribution', models.CharField(max_length=255, blank=True, null=True)),
                ('alt_text', models.CharField(max_length=255, blank=True, null=True)),
                ('caption', models.CharField(max_length=255, blank=True, null=True)),
                ('tags', taggit.managers.TaggableManager(help_text=None, verbose_name='Tags', to='taggit.Tag', blank=True, through='taggit.TaggedItem')),
                ('uploaded_by_user', models.ForeignKey(editable=False, null=True, verbose_name='Uploaded by user', to=settings.AUTH_USER_MODEL, blank=True)),
            ],
            options={
                'abstract': False,
            },
            bases=(models.Model, wagtail.wagtailadmin.taggable.TagSearchable),
        ),
        migrations.CreateModel(
            name='ImageWithAttributionRendition',
            fields=[
                ('id', models.AutoField(verbose_name='ID', primary_key=True, serialize=False, auto_created=True)),
                ('file', models.ImageField(height_field='height', width_field='width', upload_to='images')),
                ('width', models.IntegerField(editable=False)),
                ('height', models.IntegerField(editable=False)),
                ('focal_point_key', models.CharField(editable=False, default='', blank=True, max_length=255)),
                ('filter', models.ForeignKey(related_name='+', to='wagtailimages.Filter')),
                ('image', models.ForeignKey(related_name='renditions', to='kagiso_image.ImageWithAttribution')),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='imagewithattributionrendition',
            unique_together=set([('image', 'filter', 'focal_point_key')]),
        ),
    ]



from django.db import models
from django.db.models.signals import pre_delete
from django.dispatch import receiver
from wagtail.wagtailimages.models import (
    AbstractImage,
    AbstractRendition,
    Image,
)


class ImageWithAttribution(AbstractImage):
    attribution = models.CharField(max_length=255, blank=True, null=True)
    alt_text = models.CharField(max_length=255, blank=True, null=True)
    caption = models.CharField(max_length=255, blank=True, null=True)

    admin_form_fields = Image.admin_form_fields + (
        'attribution',
        'alt_text',
        'caption',
    )

    @property
    def full_url(self):
        return self.get_rendition('original').url


class ImageWithAttributionRendition(AbstractRendition):
    image = models.ForeignKey(ImageWithAttribution, related_name='renditions')

    class Meta:
        unique_together = (
            ('image', 'filter', 'focal_point_key'),
        )


# Delete the source image file when an image is deleted
@receiver(pre_delete, sender=ImageWithAttribution)
def image_delete(sender, instance, **kwargs):
    instance.file.delete(False)  # pragma: no cover


# Delete the rendition image file when a rendition is deleted
@receiver(pre_delete, sender=ImageWithAttributionRendition)
def rendition_delete(sender, instance, **kwargs):
    instance.file.delete(False)  # pragma: no cover



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import wagtail.wagtailimages.models
import taggit.managers
import wagtail.wagtailcore.models
import django.db.models.deletion
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0029_auto_20160322_1251'),
        ('kagiso_image', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='imagewithattribution',
            name='collection',
            field=models.ForeignKey(related_name='+', verbose_name='collection', default=wagtail.wagtailcore.models.get_root_collection_id, to='wagtailcore.Collection'),
        ),
        migrations.AlterField(
            model_name='imagewithattribution',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='created at', db_index=True),
        ),
        migrations.AlterField(
            model_name='imagewithattribution',
            name='file',
            field=models.ImageField(upload_to=wagtail.wagtailimages.models.get_upload_to, height_field='height', verbose_name='file', width_field='width'),
        ),
        migrations.AlterField(
            model_name='imagewithattribution',
            name='height',
            field=models.IntegerField(editable=False, verbose_name='height'),
        ),
        migrations.AlterField(
            model_name='imagewithattribution',
            name='tags',
            field=taggit.managers.TaggableManager(blank=True, through='taggit.TaggedItem', verbose_name='tags', to='taggit.Tag', help_text=None),
        ),
        migrations.AlterField(
            model_name='imagewithattribution',
            name='title',
            field=models.CharField(verbose_name='title', max_length=255),
        ),
        migrations.AlterField(
            model_name='imagewithattribution',
            name='uploaded_by_user',
            field=models.ForeignKey(blank=True, verbose_name='uploaded by user', to=settings.AUTH_USER_MODEL, null=True, editable=False, on_delete=django.db.models.deletion.SET_NULL),
        ),
        migrations.AlterField(
            model_name='imagewithattribution',
            name='width',
            field=models.IntegerField(editable=False, verbose_name='width'),
        ),
    ]



from setuptools import find_packages, setup


setup(
    name='kagiso_image',
    version='0.0.4',
    author='Kagiso Media',
    author_email='development@kagiso.io',
    description='Kagiso Image with Attribution',
    url='https://github.com/Kagiso-Future-Media/kagiso_image',
    packages=find_packages(),
    install_requires = [
        'wagtail>=1.4',
    ]
)
